@@ -91,11 +91,15 @@
   will create intermediate directories as required. Updated compatibility code
   for IDE tapes. Added entries for /dev/ide/mt hierarchy.
 
-    Last updated by Richard Gooch   4-NOV-1999: Added compatibility entries for
+    Updated by      Richard Gooch   4-NOV-1999: Added compatibility entries for
   virtual console capture, serial and console devices.
 
+    Last updated by Richard Gooch   5-NOV-1999: Added compatibility entries for
+  BSD pty devices.
+
 
 */
+#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -107,7 +111,6 @@
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <sys/ioctl.h>
-#include <unistd.h>
 #include <dirent.h>
 #include <fcntl.h>
 #include <linux/devfs_fs.h>
@@ -120,7 +123,7 @@
 #include <karma.h>
 
 
-#define VERSION "1.2.10"
+#define VERSION "1.2.11"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS (6 + 1)
 
@@ -1049,6 +1052,17 @@ static void action_compat (const struct devfsd_notify_struct *info,
 	    sprintf (compat_buf, "tty%s", info->devname + 3);
 	    compat_name = compat_buf;
 	}
+	else if (strncmp (info->devname, "pty/", 4) == 0)
+	{
+	    int index = atoi (info->devname + 5);
+	    const char *pty1 = "pqrstuvwxyzabcde";
+	    const char *pty2 = "0123456789abcdef";
+
+	    sprintf (compat_buf, "%cty%c%c",
+		     (info->devname[4] == 'm') ? 'p' : 't',
+		     pty1[index >> 4], pty2[index & 0x0f]);
+	    compat_name = compat_buf;
+	}
 	break;
       case AC_MKNEWCOMPAT:
       case AC_RMNEWCOMPAT:
@@ -1210,6 +1224,7 @@ static void action_compat (const struct devfsd_notify_struct *info,
 	else SYSLOG (LOG_INFO, "unlinked: \"%s\"\n", compat_path);
 	break;
     }
+    if (!syslog_is_open) usleep (10000);
 }   /*  End Function action_compat  */
 
 static void free_config ()
